# aioqueuerpc

JSON RPC with asyncio queues (no transport layer implementation).

## Work-in-Progress

The repository contains a module extracted from my other project and was refactored as a separate package.

## Usage Examples

```
...
```
